# -*- coding: utf-8 -*-

"""Head module.

This module implements the functionality that allows to display
the first lines of a file.
"""

from stemplate import config
from stemplate.core.colors import colorize
from stemplate.core.files import get_beginning, get_size

def setup(parser):
    """Configure the parser for the module.

    Parameters
    ----------
    parser : ArgumentParser
        Parser dedicated to the module.

    """
    parser.set_defaults(
        func=main,
    )
    parser.add_argument('file',
        help="path to the file",
        type=str,
    )
    parser.add_argument('--lines',
        help="number of lines to display",
        type=int,
    )
    parser.add_argument('--color',
        help="name of the color",
        type=str,
    )

def main(file, **kwargs):
    """Display the first lines of the file.

    Parameters
    ----------
    file : str
        Path to the file.

    Keyword Arguments
    -----------------
    lines : int
        Number of lines to display.
    color : str
        Name of the color.

    """
    file = str(file)
    lines = int(kwargs.get('lines', config.get(__name__, 'lines')))
    color = str(kwargs.get('color', config.get(__name__, 'color')))
    content = get_beginning(file, lines)
    size = get_size(file)
    colored = colorize(content, color)
    print(f"{colored}...\n(file size: {size} bytes)")
